from setuptools import setup

setup(
    name='bounce_email',
    version='0.0.1',
    description=open('README.md').read(),
    url='http://github.com/ronbeltran/bounce_email',
    author='Ronnie Beltran',
    author_email='rbbeltran.09@gmail.com',
    license='MIT',
    packages=['bounce_email'],
    zip_safe=False,
)
